@@ -7,8 +7,10 @@ from libreflow.baseflow.file import (
     Revision,
     TrackedFile,
     FileSystemMap,
-    CreateTrackedFileAction,
-    CreateTrackedFolderAction)
+    CreateTrackedFileAction, CreateFileAction,
+    CreateTrackedFolderAction, CreateFolderAction,
+    AddFilesFromExisting,
+)
 
 from kabaret.flow_contextual_dict import get_contextual_dict
 
@@ -94,7 +96,29 @@ class TrackedFile(TrackedFile):
         return self.name()
 
 
+class CreateFolderAction(CreateFolderAction):
+
+    def allow_context(self, context):
+        return False
+
+
+class CreateFileAction(CreateFileAction):
+
+    def allow_context(self, context):
+        return False
+
+
+class AddFilesFromExisting(AddFilesFromExisting):
+
+    def allow_context(self, context):
+        return False
+
+
 class FileSystemMap(FileSystemMap):
+    
+    create_untracked_folder = flow.Child(CreateFolderAction)
+    create_untracked_file = flow.Child(CreateFileAction)
+    add_files_from_existing = flow.Child(AddFilesFromExisting)
 
     def add_tracked_file(self, name, extension, complete_name):
         key = "%s_%s" % (name, extension)
