@@ -142,6 +142,32 @@ class ProjectWidget(QtWidgets.QWidget):
         self.grid_layout.addWidget(self.sequences_button, 1, 1)
         self.grid_layout.addWidget(self.assets_button, 2, 1)
 
+        try:
+            requiered_versions = self.HomePageWidget.session.cmds.Flow.call(
+                "/%s" % project, "get_requiered_versions", {}, {}
+                )
+            
+            start_line = 3
+
+            for r in requiered_versions:
+                color = "#74787a"
+                if r[3] > 0:
+                    color = "#b9c2c8"
+                required_update = ""
+                if r[3] == 1:
+                    required_update = " <strong>Update to %s available</strong>" % r[2]
+                elif r[3] == 2:
+                    required_update =  " <font color=\"red\"><strong>Update required to %s</strong></font>" % r[2]
+                text = "<font color=\"%s\">%s %s %s</font>" % (color, r[0], r[1], required_update)
+                t = QtWidgets.QLabel(text)
+                t.setMargin(20)
+                t.setAlignment(QtCore.Qt.AlignCenter | QtCore.Qt.AlignVCenter)
+                self.grid_layout.addWidget(t, start_line, 0, 3, 1)
+
+                start_line += 1
+        except:
+            pass
+
         self.setLayout(self.grid_layout)
 
     def on_project_button_clicked(self, project, button):
@@ -158,6 +184,8 @@ class ProjectWidget(QtWidgets.QWidget):
         self.HomePageWidget.page.goto(oid)
 
 
+
+
 class ProjectHomePageWidget(CustomPageWidget):
     def build(self):
         self.projectsButtons = {}
@@ -168,3 +196,4 @@ class ProjectHomePageWidget(CustomPageWidget):
 
             project_list.addWidget(ProjectWidget(None, name, self))
         self.setLayout(project_list)
+
